<?php
/**
 * Smarty plugin
 * @package Smarty
 * @subpackage plugins
 */


/**
 * Smarty {giveurl} function plugin
 *
 * Type:     function<br>
 * Name:     giveurl<br>
 * Date:     june 03, 2008
 * Purpose:  Givr url.<br>
 * Input:<br>
 *         - address = e-mail address
 *         - text = (optional) text to display, default is address
 *         - encode = (optional) can be one of:
 *                * none : no encoding (default)
 *                * javascript : encode with javascript
 *                * javascript_charcode : encode with javascript charcode
 *                * hex : encode with hexidecimal (no javascript)
 *         - cc = (optional) address(es) to carbon copy
 *         - bcc = (optional) address(es) to blind carbon copy
 *         - subject = (optional) e-mail subject
 *         - newsgroups = (optional) newsgroup(s) to post to
 *         - followupto = (optional) address(es) to follow up to
 *         - extra = (optional) extra tags for the href link
 *
 * Examples:
 * <pre>
 * {mailto address="me@domain.com"}
 * {mailto address="me@domain.com" encode="javascript"}
 * {mailto address="me@domain.com" encode="hex"}
 * {mailto address="me@domain.com" subject="Hello to you!"}
 * {mailto address="me@domain.com" cc="you@domain.com,they@domain.com"}
 * {mailto address="me@domain.com" extra='class="mailto"'}
 * </pre>
 * @link http://smarty.php.net/manual/en/language.function.mailto.php {mailto}
 *          (Smarty online manual)
 * @version  1.2
 * @author   Monte Ohrt <monte at ohrt dot com>
 * @author   credits to Jason Sweat (added cc, bcc and subject functionality)
 * @param    array
 * @param    Smarty
 * @return   string
 */
function smarty_function_giveurl($params, &$smarty)
{
	$SITE_ROOT = $GLOBALS['SITE_ROOT'];
	$url_rewrite = get_option("url_rewriting");
	
	$extranet = (empty($params['extranet'])) ? '' : $params['extranet'];
	$path = (empty($params['path'])) ? '%NO_PATH%' : $params['path'];
	$file = (empty($params['file'])) ? 'index' : $params['file'];
	$qs = (empty($params['qs'])) ? '' : $params['qs'];
	$format = (empty($params['format'])) ? 'long' : $params['format'];
	
	$ret = "";
	
	if($path != '%NO_PATH%')
	{
		if (substr($path,strlen($path)-1,1) != "/")
		{
			$path .= "/";
		}
	}
	
	if($url_rewrite == "0")
	{
		#No Rewriting !
		if(strlen($qs) > 0)
		{
			$qs = "&".$qs;
		}
		if ($format == "long")
		{
			$ret = $SITE_ROOT.$file.".php?ext_name=".$extranet."&path=".$path.$qs;
		}
		else
		{
			$ret = $file.".php?ext_name=".$extranet."&path=".$path.$qs;
		}
		$ret = str_replace("&path=%NO_PATH%","",$ret);
	}
	else
	{
		#Rewriting !
		if(strlen($qs) > 0)
		{
			$qs = "?".$qs;
		}
		if ($format == "long")
		{
			$ret = $SITE_ROOT.$extranet."/".$path.$file.".php".$qs;
		}
		else
		{
			$ret = $extranet."/".$path.$file.".php".$qs;
		}
		
		$ret = str_replace("index.php","",$ret);
		$ret = str_replace("%NO_PATH%","",$ret);
	}
	
	return $ret;
	
}

/* vim: set expandtab: */

?>
